@@ -32,6 +32,17 @@ class OpenBabelMixin:
         for row in self.bonds.bonds():
             ob_mol.AddBond(index[row["i"]], index[row["j"]], row["bondorder"])
 
+        if self.__class__.__name__ == " _Configuration":
+            ob_mol.SetTotalCharge(self.charge)
+            if self.spin_multiplicity is None:
+                n_electrons = sum(self.atoms.atomic_numbers) - self.charge
+                if n_electrons % 2 == 0:
+                    multiplicity = 1
+                else:
+                    multiplicity = 2
+                self.spin_multiplicity = multiplicity
+                ob_mol.SetTotalSpinMultiplicity(self.spin_multiplicity)
+
         return ob_mol
 
     def from_OBMol(self, ob_mol):
@@ -63,6 +74,11 @@ class OpenBabelMixin:
             logger.debug(f"bond {i} - {j} {bondorder}")
 
         self.clear()
+
+        if self.__class__.__name__ == "_Configuration":
+            self.charge = ob_mol.GetTotalCharge()
+            self.spin_multiplicity = ob_mol.GetTotalSpinMultiplicity()
+
         ids = self.atoms.append(x=Xs, y=Ys, z=Zs, atno=atnos)
         i = [ids[x - 1] for x in Is]
         j = [ids[x - 1] for x in Js]
